@@ -94,8 +94,12 @@ def _write_blame():
     blamefile = tempfile.NamedTemporaryFile()
     blamefile.write(_get_blame())
     blamefile.seek(0) # Rewind the file so that the putter can read it.
-    put(blamefile.name, '/'.join([env.workdir, 'blame.yaml']))
-    os.remove(blamefile)
+    remote_blame = '/'.join([env.workdir, 'blame.yaml'])
+    put(blamefile.name, remote_blame)
+    blamefile.close()
+
+    # Fix the permissions on the remote blame file
+    sudo('chmod +r %s' % remote_blame)
 
 def reload():
     """
